summaryrefslogtreecommitdiffstats
path: root/src/basket.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit631d7b9b0878ca3842496b5719f9c5803335e150 (patch)
treed09fe0c8cd6edfd28c9c7947b0af60ccc75fbb8d /src/basket.h
parent33f08e93132a53bf14f41f5f1e567eeea832b336 (diff)
downloadbasket-631d7b9b0878ca3842496b5719f9c5803335e150.tar.gz
basket-631d7b9b0878ca3842496b5719f9c5803335e150.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/basket@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/basket.h')
-rw-r--r--src/basket.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/basket.h b/src/basket.h
index fd35a8b..ec7bc8a 100644
--- a/src/basket.h
+++ b/src/basket.h
@@ -59,7 +59,7 @@ class DiskErrorDialog : public KDialogBase
Q_OBJECT
TQ_OBJECT
public:
- DiskErrorDialog(const TQString &titleMessage, const TQString &message, TQWidget *tqparent = 0);
+ DiskErrorDialog(const TQString &titleMessage, const TQString &message, TQWidget *parent = 0);
~DiskErrorDialog();
protected:
void closeEvent(TQCloseEvent *event);
@@ -87,11 +87,11 @@ namespace PlugOptions
class NoteSelection
{
public:
- NoteSelection() : note(0), tqparent(0), firstChild(0), next(0), fullPath() {}
- NoteSelection(Note *n) : note(n), tqparent(0), firstChild(0), next(0), fullPath() {}
+ NoteSelection() : note(0), parent(0), firstChild(0), next(0), fullPath() {}
+ NoteSelection(Note *n) : note(n), parent(0), firstChild(0), next(0), fullPath() {}
Note *note;
- NoteSelection *tqparent;
+ NoteSelection *parent;
NoteSelection *firstChild;
NoteSelection *next;
TQString fullPath; // Needeed for 'Cut' code to store temporary path of the cutted note.
@@ -128,7 +128,7 @@ class DecoratedBasket : public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- DecoratedBasket(TQWidget *tqparent, const TQString &folderName, const char *name = 0, WFlags fl = 0);
+ DecoratedBasket(TQWidget *parent, const TQString &folderName, const char *name = 0, WFlags fl = 0);
~DecoratedBasket();
void setFilterBarPosition(bool onTop);
void resetFilter();
@@ -150,7 +150,7 @@ class TransparentWidget : public TQWidget
public:
TransparentWidget(Basket *basket);
void setPosition(int x, int y);
- //void reparent(TQWidget *tqparent, WFlags f, const TQPoint &p, bool showIt = FALSE);
+ //void reparent(TQWidget *parent, WFlags f, const TQPoint &p, bool showIt = FALSE);
protected:
void paintEvent(TQPaintEvent*);
void mouseMoveEvent(TQMouseEvent *event);
@@ -177,7 +177,7 @@ class Basket : public TQScrollView, public TQToolTip
};
public:
- Basket(TQWidget *tqparent, const TQString &folderName);
+ Basket(TQWidget *parent, const TQString &folderName);
~Basket();
/// USER INTERACTION:
@@ -230,7 +230,7 @@ class Basket : public TQScrollView, public TQToolTip
/// NOTES INSERTION AND REMOVAL:
public:
/// The following methods assume that the note(s) to insert already all have 'this' as the tqparent basket:
void prependNoteIn( Note *note, Note *in); /// << Add @p note (and the next linked notes) as the first note(s) of the group @p in.
void appendNoteIn( Note *note, Note *in); /// << Add @p note (and the next linked notes) as the last note(s) of the group @p in.
void appendNoteAfter( Note *note, Note *after); /// << Add @p note (and the next linked notes) just after (just below) the note @p after.
@@ -309,8 +309,8 @@ class Basket : public TQScrollView, public TQToolTip
void enableActions();
private slots:
- void loadNotes(const TQDomElement &notes, Note *tqparent);
- void saveNotes(TQDomDocument &document, TQDomElement &element, Note *tqparent);
+ void loadNotes(const TQDomElement &notes, Note *parent);
+ void saveNotes(TQDomDocument &document, TQDomElement &element, Note *parent);
void unlock();
protected slots:
void inactivityAutoLockTimeout();
@@ -743,7 +743,7 @@ clas s Bas ket : public TQScrollView
TQ_OBJECT
public:
/** Construtor and destructor */
- Bask et(TQWidget *tqparent, const TQString &folderName, const char *name = "", WFlags fl = 0);
+ Bask et(TQWidget *parent, const TQString &folderName, const char *name = "", WFlags fl = 0);
public:
protected:
virtual void contentsContextMenuEvent(TQContextMenuEvent *event);
@@ -230,7 +230,7 @@ class Basket : public TQScrollView, public TQToolTip
/// NOTES INSERTION AND REMOVAL:
public:
- /// The following methods assume that the note(s) to insert already all have 'this' as the tqparent basket:
+ /// The following methods assume that the note(s) to insert already all have 'this' as the parent basket:
void prependNoteIn( Note *note, Note *in); /// << Add @p note (and the next linked notes) as the first note(s) of the group @p in.
void appendNoteIn( Note *note, Note *in); /// << Add @p note (and the next linked notes) as the last note(s) of the group @p in.